@@ -114,67 +114,67 @@ class RoborockFanPowerCode(RoborockEnum):
 
 
 class RoborockFanSpeedV1(RoborockFanPowerCode):
-    Silent = 38
-    Standard = 60
-    Medium = 77
-    Turbo = 90
+    silent = 38
+    standard = 60
+    medium = 77
+    turbo = 90
 
 
 class RoborockFanSpeedV2(RoborockFanPowerCode):
-    Silent = 101
-    Balanced = 102
-    Turbo = 103
-    Max = 104
-    Gentle = 105
-    Auto = 106
+    silent = 101
+    balanced = 102
+    turbo = 103
+    max = 104
+    gentle = 105
+    auto = 106
 
 
 class RoborockFanSpeedV3(RoborockFanPowerCode):
-    Silent = 38
-    Standard = 60
-    Medium = 75
-    Turbo = 100
+    silent = 38
+    standard = 60
+    medium = 75
+    turbo = 100
 
 
 class RoborockFanSpeedE2(RoborockFanPowerCode):
-    Gentle = 41
-    Silent = 50
-    Standard = 68
-    Medium = 79
-    Turbo = 100
+    gentle = 41
+    silent = 50
+    standard = 68
+    medium = 79
+    turbo = 100
 
 
 class RoborockFanSpeedS7(RoborockFanPowerCode):
-    Off = 105
-    Quiet = 101
-    Balanced = 102
-    Turbo = 103
-    Max = 104
-    Custom = 106
+    off = 105
+    quiet = 101
+    balanced = 102
+    turbo = 103
+    max = 104
+    custom = 106
 
 
 class RoborockFanSpeedS7MaxV(RoborockFanPowerCode):
-    Off = 105
-    Quiet = 101
-    Balanced = 102
-    Turbo = 103
-    Max = 104
-    Max_plus = 108
+    off = 105
+    quiet = 101
+    balanced = 102
+    turbo = 103
+    max = 104
+    max_plus = 108
 
 
 class RoborockFanSpeedS6Pure(RoborockFanPowerCode):
-    Gentle = 105
-    Quiet = 101
-    Balanced = 102
-    Turbo = 103
-    Max = 104
+    gentle = 105
+    quiet = 101
+    balanced = 102
+    turbo = 103
+    max = 104
 
 
 class RoborockFanSpeedQ7Max(RoborockFanPowerCode):
-    Quiet = 101
-    Balanced = 102
-    Turbo = 103
-    Max = 104
+    quiet = 101
+    balanced = 102
+    turbo = 103
+    max = 104
 
 
 class RoborockMopModeCode(RoborockEnum):
